@@ -192,6 +192,8 @@ public class DirectLinkGenerator {
                     .replaceAll("\\[folder\\]", file.getFolderId())
                     .replaceAll("\\[object\\]", file.getId())
                     .replaceAll("\\[version\\]", null == file.getVersion() ? "0" : file.getVersion())
+                    .replaceAll("\\[contextid\\]", String.valueOf(session.getServerSession().getContextId()))
+                    .replaceAll("\\[userid\\]", String.valueOf(session.getServerSession().getUserId()))
                     .replaceAll("\\[width\\]", String.valueOf(width))
                     .replaceAll("\\[height\\]", String.valueOf(height))
                 ;
@@ -204,6 +206,8 @@ public class DirectLinkGenerator {
                     .replaceAll("\\[folder\\]", file.getFolderId())
                     .replaceAll("\\[object\\]", file.getId())
                     .replaceAll("\\[version\\]", null == file.getVersion() ? "0" : file.getVersion())
+                    .replaceAll("\\[contextid\\]", String.valueOf(session.getServerSession().getContextId()))
+                    .replaceAll("\\[userid\\]", String.valueOf(session.getServerSession().getUserId()))
                     .replaceAll("\\[width\\]", String.valueOf(width))
                     .replaceAll("\\[height\\]", String.valueOf(height))
                 ;
@@ -218,6 +222,8 @@ public class DirectLinkGenerator {
                     .replaceAll("\\[folder\\]", file.getFolderId())
                     .replaceAll("\\[object\\]", file.getId())
                     .replaceAll("\\[version\\]", null == file.getVersion() ? "0" : file.getVersion())
+                    .replaceAll("\\[contextid\\]", String.valueOf(session.getServerSession().getContextId()))
+                    .replaceAll("\\[userid\\]", String.valueOf(session.getServerSession().getUserId()))
                     .replaceAll("\\[width\\]", String.valueOf(width))
                     .replaceAll("\\[height\\]", String.valueOf(height))
                 ;
