@@ -393,7 +393,8 @@ public class FileActionExecutor extends BatchActionExecutor<FileVersion> {
              * check if versions already known in trash if applicable
              */
             if (OPTIMISTIC_MOVE_TO_TEMP_THRESHOLD < versionsToRemove.size() && session.getTemp().exists()) {
-                FileStorageFolder tempFolder = session.getStorage().optFolder(session.getTemp().getPath(false));
+                String tempPath = session.getTemp().getPath(false);
+                FileStorageFolder tempFolder = null != tempPath ? session.getStorage().optFolder(tempPath) : null;
                 if (null != tempFolder) {
                     List<FileChecksum> knownChecksums = session.getChecksumStore().getFileChecksums(new FolderID(tempFolder.getId()));
                     if (null != knownChecksums && 0 < knownChecksums.size()) {
@@ -478,12 +479,15 @@ public class FileActionExecutor extends BatchActionExecutor<FileVersion> {
 
     private static boolean isFromTemp(SyncSession session, File file) throws OXException {
         if (session.getTemp().exists()) {
-            String tempFolderID = session.getStorage().getFolderID(session.getTemp().getPath(true));
-            if (tempFolderID.equals(file.getFolderId())) {
-                return true;
+            String tempPath = session.getTemp().getPath(true);
+            if (null != tempPath) {
+                String tempFolderID = session.getStorage().getFolderID(tempPath);
+                if (tempFolderID.equals(file.getFolderId())) {
+                    return true;
+                }
+                FileStorageFolder folder = session.getStorage().getFolderAccess().getFolder(file.getFolderId());
+                return null != folder && tempFolderID.equals(folder.getParentId());
             }
-            FileStorageFolder folder = session.getStorage().getFolderAccess().getFolder(file.getFolderId());
-            return null != folder && tempFolderID.equals(folder.getParentId());
         }
         return false;
     }
